@@ -1,4 +1,4 @@
-# $Id: /mirror/gungho/lib/Gungho/Engine/POE.pm 31116 2007-11-26T13:09:51.933010Z lestrrat  $
+# $Id: /mirror/gungho/lib/Gungho/Engine/POE.pm 35439 2007-12-17T05:32:05.323703Z kazuhooku  $
 #
 # Copyright (c) 2007 Daisuke Maki <daisuke@endeworks.jp>
 # All rights reserved.
@@ -113,7 +113,7 @@ sub run
     # PoCo::Client::HTTP 0.82, PoCo::Client::HTTP tended to get filled up
     # pretty quickcly)
     $self->clients( [] );
-    my $spawn = $client_config->{spawn} || 2;
+    my $spawn = delete $client_config->{Spawn} || 2;
     if ($spawn < 1) { $spawn = 2 }
     for my $i ( 1 .. $spawn ) {
         my $alias = join('-', &UserAgentAlias, $i);
@@ -470,14 +470,16 @@ Sends a request to the http client
 =head1 CAVEATS
 
 The POE engine supports multiple values in the user-agent header, but this
-is an exception. To be portable with other engines, and if you are using only
-one user-agent, set it at the top level:
+is an exception that other engines don't support. Please use define your
+agent strings in the top level config:
 
   user_agent: my_user_agent
   engine:
     module: POE
     ...
 
+If you don't do this, components such as RobotRules won't work properly
+
 =head1 TODO
 
 Xango, Gungho's predecessor, tried really hard to overcome one of my pet-peeves
